==> haskell-hspec-core-2.10.9-185-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-core
version:              2.10.9
visibility:           public
id:                   hspec-core-2.10.9-3eN0cOsqzg09qONPnFaA50
key:                  hspec-core-2.10.9-3eN0cOsqzg09qONPnFaA50
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  6b61dd7d96073c4352dd8acb7c3a36dc
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.10.9-3eN0cOsqzg09qONPnFaA50
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-9XJxSbkIGB4JeqA96RzyUI
    ansi-terminal-1.0.2-HBeoENQnxizF4CvHZENnzA array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    haskell-lexer-1.1.1-Hpax8yMtr9r8FzGXIYjm8Z
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568 process-1.6.18.0
    quickcheck-io-0.2.0-F0mnYH2m8BBHJfWZxBQ5kW
    random-1.2.1.2-F2QY00F1ipP5r5x8nqIATJ
    setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb stm-2.5.1.0
    tf-random-0.5-84xtL3JkfLjErXxS1TXnJR time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.10.9-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-core
version:              2.10.9
visibility:           public
id:                   hspec-core-2.10.9-Cd4RSMldMfnLVgHkL2swTJ
key:                  hspec-core-2.10.9-Cd4RSMldMfnLVgHkL2swTJ
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  152cd1cbb428be8fd183876649317a0c
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.10.9-Cd4RSMldMfnLVgHkL2swTJ
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-C8cZng3OFrO55aPQ2PJVj0
    ansi-terminal-1.0.2-EhzJoAzi53XHL1K3CBirLP array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    haskell-lexer-1.1.1-Hpax8yMtr9r8FzGXIYjm8Z
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568 process-1.6.18.0
    quickcheck-io-0.2.0-9rpEeV9jIOUJEtRRtbqdxG
    random-1.2.1.2-DeKikqVo0OAEnmZVxkkmVK
    setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb stm-2.5.1.0
    tf-random-0.5-3rPHj1mQWEY665byKlZ34a time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
